cdio_driver_errmsg

Function cdio_driver_errmsg 

pub unsafe extern "C" fn cdio_driver_errmsg(
    drc: driver_return_code_t,
) -> *const c_char
@brief Get error message string for a driver return code.

@param drc The return code to be interpreted. @return The string description of the return code \p drc, or a generic error message if \p drc is unrecognized.