cdio_get_cdtext

Function cdio_get_cdtext 

pub unsafe extern "C" fn cdio_get_cdtext(
    p_cdio: *mut CdIo_t,
) -> *mut cdtext_t
Return a pointer to the cdtext_t object which is attached to a CdIo_t object. If no such cdtext_t is attached yet, then try to read CD-TEXT information and use it to create and initialise the cdtext_t object.

For usage of cdtext_t see include file <cdio/cdtext.h>.

@param p_cdio the CD object that may contain CD-Text information. @return a pointer to the attached cdtext_t object or NULL if problems occur or if CD-Text information does not exist.