pub unsafe extern "C" fn cdio_get_cdtext_raw(
p_cdio: *mut CdIo_t,
) -> *mut u8Expand description
Read cdtext information for a cdtext_t object. About format and usage of these data see the documentation of call mmc_read_cdtext() in include file <cdio/mmc.h>.
@param p_cdio the CD object that may contain CD-Text information. @return malloc’d pointer to raw CD-Text data as replied by the drive or NULL if problems occur or CD-Text information does not exist. A non-NULL return value must be freed with cdio_free() when done.