cdio_get_default_device_linux

Function cdio_get_default_device_linux 

pub unsafe extern "C" fn cdio_get_default_device_linux() -> *mut c_char
Return a string containing the default device name that the GNU/Linux driver would use when none is specified. A scan is made for CD-ROM drives with CDs in them.

NULL is returned on error or there is no CD-ROM device.

In some situations of drivers or OS’s we can’t find a CD device if there is no media in it and it is possible for this routine to return NULL even though there may be a hardware CD-ROM.

@see cdio_open_cd, cdio_open