pub unsafe extern "C" fn cdio_get_devices(
driver_id: driver_id_t,
) -> *mut *mut c_charExpand description
Return an array of device names. If you want a specific devices for a driver, give that device. If you want hardware devices, give \p DRIVER_DEVICE and if you want all possible devices, image drivers and hardware drivers give \p DRIVER_UNKNOWN.
NULL is returned if we couldn’t return a list of devices.
In some situations of drivers or OS’s we can’t find a CD device if there is no media in it and it is possible for this routine to return \p NULL even though there may be a hardware CD-ROM.