cdio_log_set_handler

Function cdio_log_set_handler 

pub unsafe extern "C" fn cdio_log_set_handler(
    new_handler: cdio_log_handler_t,
) -> cdio_log_handler_t
Set a custom log handler for libcdio. The return value is the log handler being replaced. If the provided parameter is NULL, then the handler will be reset to the default handler.

@see cdio_log_handler_t

@param new_handler The new log handler. @return The previous log handler.