pub unsafe extern "C" fn cdio_open(
psz_source: *const c_char,
driver_id: driver_id_t,
) -> *mut CdIo_tExpand description
Sets up to read from place specified by \p psz_source and \p driver_id. This or cdio_open_* should be called before using any other routine, except cdio_init or any routine that accesses the CD-ROM drive by name. cdio_open will call cdio_init, if that hasn’t been done previously.
@return the cdio object or NULL on error or no device. If NULL is given as the source, we’ll use the default driver device.