pub unsafe extern "C" fn cdio_open_linux(
psz_source: *const c_char,
) -> *mut CdIo_tExpand description
Set up CD-ROM for reading using the GNU/Linux driver. The device_name is the some sort of device name.
@return the cdio object for subsequent operations. NULL on error or there is no GNU/Linux driver.
In some situations of drivers or OS’s we can’t find a CD device if there is no media in it and it is possible for this routine to return NULL even though there may be a hardware CD-ROM.