pub unsafe extern "C" fn cdio_read_sector(
p_cdio: *const CdIo_t,
p_buf: *mut c_void,
i_lsn: lsn_t,
read_mode: cdio_read_mode_t,
) -> driver_return_code_tExpand description
The special case of reading a single block is a common one so we provide a routine for that as a convenience.