udf_read_block

Function udf_read_block 

pub unsafe extern "C" fn udf_read_block(
    p_udf_dirent: *const udf_dirent_t,
    buf: *mut c_void,
    count: usize,
) -> isize
Attempts to read up to count blocks from UDF directory entry p_udf_dirent into the buffer starting at buf. buf must be large enough to store count * UDF_BLOCKSIZE bytes. Reading continues after the point at which we last read or from the beginning the first time.

If count is zero, read() returns zero and has no other results. If count is greater than SSIZE_MAX, the result is unspecified.

On success, returns the number of bytes read. If there is an error, cast the result to driver_return_code_t for the specific error code.