udf_readdir

Function udf_readdir 

pub unsafe extern "C" fn udf_readdir(
    p_udf_dirent: *mut udf_dirent_t,
) -> *mut udf_dirent_t
Advances p_udf_direct to the the next directory entry in the pointed to by p_udf_dir. It also returns this as the value. NULL is returned on reaching the end-of-file or if an error. Also p_udf_dirent is free’d. If the end of is not reached the caller must call udf_dirent_free() with p_udf_dirent when done with it to release resources.