udf_setpos

Function udf_setpos 

pub unsafe extern "C" fn udf_setpos(
    p_udf_dirent: *mut udf_dirent_t,
    offset: off_t,
) -> bool
Seek to a specific offset in a UDF file. The offset must be a multiple of UDF_BLOCKSIZE. Returns true if the position was successfully changed, or false on any error condition (such as offset out of range or not aligned to UDF_BLOCKSIZE).