#[repr(C)]pub struct cdio_iso_analysis_t {
pub joliet_level: c_uint,
pub iso_label: [c_char; 33],
pub isofs_size: c_uint,
pub UDFVerMinor: u8,
pub UDFVerMajor: u8,
}Expand description
\brief The type used to return analysis information from cdio_guess_cd_type.
These fields make sense only for when an ISO-9660 filesystem is used.
Fields
joliet_level: c_uint< If has Joliet extensions, this is the associated level number (i.e. 1, 2, or 3).
iso_label: [c_char; 33]< This is 32 + 1 for null byte at the end in formatting the string
isofs_size: c_uintUDFVerMinor: u8< For UDF filesystems only
UDFVerMajor: u8< For UDF filesystems only