cdrom_drive_s

Struct cdrom_drive_s 

#[repr(C)]
pub struct cdrom_drive_s {
Show 27 fields pub p_cdio: *mut CdIo_t, pub opened: c_int, pub cdda_device_name: *mut c_char, pub drive_model: *mut c_char, pub drive_type: c_int, pub bigendianp: c_int, pub nsectors: c_int, pub cd_extra: c_int, pub b_swap_bytes: bool, pub tracks: track_t, pub disc_toc: [TOC_t; 100], pub audio_first_sector: lsn_t, pub audio_last_sector: lsn_t, pub errordest: c_int, pub messagedest: c_int, pub errorbuf: *mut c_char, pub messagebuf: *mut c_char, pub enable_cdda: Option<unsafe extern "C" fn(d: *mut cdrom_drive_t, onoff: c_int) -> c_int>, pub read_toc: Option<unsafe extern "C" fn(d: *mut cdrom_drive_t) -> c_int>, pub read_audio: Option<unsafe extern "C" fn(d: *mut cdrom_drive_t, p: *mut c_void, begin: lsn_t, sectors: c_long) -> c_long>, pub set_speed: Option<unsafe extern "C" fn(d: *mut cdrom_drive_t, speed: c_int) -> c_int>, pub error_retry: c_int, pub report_all: c_int, pub is_atapi: c_int, pub is_mmc: c_int, pub last_milliseconds: c_int, pub i_test_flags: c_int,
}
\brief Structure for cdparanoia’s CD-ROM access

Fields

p_cdio: *mut CdIo_topened: c_int

< This struct may just represent a candidate for opening

cdda_device_name: *mut c_chardrive_model: *mut c_chardrive_type: c_intbigendianp: c_int

< Whether data returned on the CDDA is bigendian or not. 1 if big endian, 0 if little endian and -1 if we don’t know.

nsectors: c_int

< Number of sectors use in reading. Multiply by CDIO_CD_FRAMESIZE_RAW to get number of bytes used in the read buffer.

cd_extra: c_int

< -1 if we can’t get multisession info, 0 if there is one session only or the multi-session LBA is less than or 100 (don’t ask me why – I don’t know), and 1 if the multi-session lba is greater than 100.

b_swap_bytes: bool

< Swap bytes if Endian-ness of drive mismatches the endian-ness of the computer?

tracks: track_tdisc_toc: [TOC_t; 100]

< info here starts origin 0 rather than the first track number (usually 1). So to take a track number and use it here, subtract off cdio_get_first_track_num() beforehand.

audio_first_sector: lsn_taudio_last_sector: lsn_terrordest: c_intmessagedest: c_interrorbuf: *mut c_charmessagebuf: *mut c_charenable_cdda: Option<unsafe extern "C" fn(d: *mut cdrom_drive_t, onoff: c_int) -> c_int>read_toc: Option<unsafe extern "C" fn(d: *mut cdrom_drive_t) -> c_int>read_audio: Option<unsafe extern "C" fn(d: *mut cdrom_drive_t, p: *mut c_void, begin: lsn_t, sectors: c_long) -> c_long>set_speed: Option<unsafe extern "C" fn(d: *mut cdrom_drive_t, speed: c_int) -> c_int>error_retry: c_intreport_all: c_intis_atapi: c_intis_mmc: c_intlast_milliseconds: c_inti_test_flags: c_int

< Normally set 0. But if we are testing paranoia operation this can be set to one of the flag masks to simulate a particular kind of failure.