#[repr(C, packed(1))]pub struct iso_rock_tf_s {
pub flags: u8,
pub time_bytes: __IncompleteArrayField<u8>,
}Expand description
Time stamp(s) for a file. See Rock Ridge Section 4.1.6
Fields
flags: u8< See ISO_ROCK_TF_* bits above.
time_bytes: __IncompleteArrayField<u8>< A homogeneous array of iso9660_ltime_t or iso9660_dtime_t entries depending on flags & ISO_ROCK_TF_LONG_FORM. Lacking a better method, we store this as an array of bytes and a cast to the appropriate type will have to be made before extraction.