udf_file_entry_s

Struct udf_file_entry_s 

#[repr(C, packed(1))]
pub struct udf_file_entry_s {
Show 21 fields pub tag: udf_tag_t, pub icb_tag: udf_icbtag_t, pub uid: udf_Uint32_t, pub gid: udf_Uint32_t, pub permissions: udf_Uint32_t, pub link_count: udf_Uint16_t, pub rec_format: udf_Uint8_t, pub rec_disp_attr: udf_Uint8_t, pub rec_len: udf_Uint32_t, pub info_len: udf_Uint64_t, pub logblks_recorded: udf_Uint64_t, pub access_time: udf_timestamp_t, pub modification_time: udf_timestamp_t, pub attribute_time: udf_timestamp_t, pub checkpoint: udf_Uint32_t, pub ext_attr_ICB: udf_long_ad_t, pub imp_id: udf_regid_t, pub unique_ID: udf_Uint64_t, pub u_extended_attr: udf_Uint32_t, pub u_alloc_descs: udf_Uint32_t, pub u: udf_file_entry_s__bindgen_ty_1,
}
File Entry (ECMA 167r3 4/14.9)

Fields

tag: udf_tag_ticb_tag: udf_icbtag_t

< 4/14.9.2

uid: udf_Uint32_t

< 4/14.9.3

gid: udf_Uint32_t

< 4/14.9.4

permissions: udf_Uint32_t

< 4/14.9.5

link_count: udf_Uint16_t

< 4/14.9.6

rec_format: udf_Uint8_t

< 4/14.9.7

rec_disp_attr: udf_Uint8_t

< 4/14.9.8

rec_len: udf_Uint32_t

< 4/14.9.9

info_len: udf_Uint64_t

< 4/14.9.10

logblks_recorded: udf_Uint64_t

< 4/14.9.11

access_time: udf_timestamp_t

< 4/14.9.12 - last access to any stream of file prior to recording file entry

modification_time: udf_timestamp_t

< 4/14.9.13 - last access to modification to any stream of file

attribute_time: udf_timestamp_tcheckpoint: udf_Uint32_text_attr_ICB: udf_long_ad_timp_id: udf_regid_tunique_ID: udf_Uint64_tu_extended_attr: udf_Uint32_tu_alloc_descs: udf_Uint32_tu: udf_file_entry_s__bindgen_ty_1