pub type driver_id_t = c_uint;Expand description
The driver_id_t enumerations may be used to tag a specific driver that is opened or is desired to be opened. Note that this is different than what is available on a given host.
Order should not be changed lightly because it breaks the ABI. One is not supposed to iterate over the values, but iterate over the cdio_drivers and cdio_device_drivers arrays.
NOTE: IF YOU MODIFY ENUM MAKE SURE INITIALIZATION IN CDIO.C AGREES.