msf_t

Type Alias msf_t 

pub type msf_t = msf_s;
\brief MSF (minute/second/frame) structure

One CD-ROMs addressing scheme especially used in audio formats (Red Book) is an address by minute, sector and frame which BCD-encoded in three bytes. An alternative format is an lba_t.

Note: the fields in this structure are BCD encoded. Use cdio_to_bcd8() or cdio_from_bcd8() to convert an integer into or out of this format. The format specifier %x (not %d) can be used if you need to format or print values in this structure.

@see lba_t

Aliased Type

#[repr(C, packed(1))]
pub struct msf_t { pub m: u8, pub s: u8, pub f: u8, }

Fields

m: u8s: u8f: u8