pub unsafe extern "C" fn cdio_close_tray(
psz_drive: *const c_char,
p_driver_id: *mut driver_id_t,
) -> driver_return_code_tExpand description
@brief Close media tray in CD drive if there is a routine to do so.
@param psz_drive The name of CD-ROM to be closed. If NULL, the default device will be used. @param p_driver_id The driver to be used or that was used if it was \p DRIVER_UNKNOWN or \p DRIVER_DEVICE. If this is \p NULL, the driver used will not be reported back. @return DRIVER_OP_SUCCESS on success, or a negative driver_return_code_t value on error.