pub unsafe extern "C" fn cdio_get_device_fd(
p_cdio: *mut CdIo_t,
) -> c_intExpand description
Get access to the underlying device file descriptor of the driver.
@param p_cdio the CD object. @return the file descriptor or DRIVER_OP_UNSUPPORTED if the device does not use file descriptors.