pub unsafe extern "C" fn cdio_get_track(
p_cdio: *const CdIo_t,
lsn: lsn_t,
) -> track_tExpand description
Find the track which contains lsn. CDIO_INVALID_TRACK is returned if the lsn outside of the CD or if there was some error.
If the lsn is before the pregap of the first track 0 is returned. Otherwise we return the track that spans the lsn.