pub unsafe extern "C" fn cdio_open_am(
psz_source: *const c_char,
driver_id: driver_id_t,
psz_access_mode: *const c_char,
) -> *mut CdIo_tExpand description
Sets up to read from place specified by psz_source, driver_id and access mode. This or cdio_open* should be called before using any other routine, except cdio_init or any routine that accesses the CD-ROM drive by name. This will call cdio_init, if that hasn’t been done previously.
If \p NULL is given as the source, we’ll use the default driver device.
@return the cdio object or \p NULL on error or no device.