pub unsafe extern "C" fn cdio_read_data_sectors(
p_cdio: *const CdIo_t,
p_buf: *mut c_void,
i_lsn: lsn_t,
i_blocksize: u16,
i_blocks: u32,
) -> driver_return_code_tExpand description
Read data sectors
@param p_cdio object to read from @param p_buf place to read data into. The caller should make sure this location can store at least ISO_BLOCKSIZE, M2RAW_SECTOR_SIZE, or M2F2_SECTOR_SIZE depending on the kind of sector getting read. If you don’t know whether you have a Mode 1/2, Form 1/ Form 2/Formless sector best to reserve space for the maximum, M2RAW_SECTOR_SIZE. @param i_lsn sector to read @param i_blocksize size of block. Should be either CDIO_CD_FRAMESIZE, M2RAW_SECTOR_SIZE, or M2F2_SECTOR_SIZE. See comment above under p_buf.
@param i_blocks number of blocks to read