pub unsafe extern "C" fn cdio_set_speed(
p_cdio: *const CdIo_t,
i_drive_speed: c_int,
) -> driver_return_code_tExpand description
Set the drive speed.
@param p_cdio CD structure set by cdio_open().
@param i_drive_speed speed in CD-ROM speed units. Note this not Kbs as would be used in the MMC spec or in mmc_set_speed(). To convert CD-ROM speed units to Kbs, multiply the number by 176 (for raw data) and by 150 (for filesystem data). On many CD-ROM drives, specifying a value too large will result in using the fastest speed.
@see mmc_set_speed() and mmc_set_drive_speed()