pub unsafe extern "C" fn cdtext_list_languages(
p_cdtext: *const cdtext_t,
) -> *mut cdtext_lang_tExpand description
@deprecated Use cdtext_list_languages_v2()
Returns a list of available languages or NULL.
WARNING: The indices in the returned array do not match the indexing as expected by cdtext_set_language_index(). Use cdtext_select_language() with the values of array elements.
Internally the list is stored in a static array.
@param p_cdtext the CD-TEXT object @return NULL if p_cdtext is NULL, or an array of 8 cdtext_lang_t elements: CDTEXT_LANGUAGE_UNKNOWN not only marks language code 0x00 but also invalid language codes and invalid language blocks.