pub unsafe extern "C" fn mmc_run_cmd(
p_cdio: *const CdIo_t,
i_timeout_ms: c_uint,
p_cdb: *const mmc_cdb_t,
e_direction: cdio_mmc_direction_t,
i_buf: c_uint,
p_buf: *mut c_void,
) -> driver_return_code_tExpand description
Run a Multimedia command (MMC).
@param p_cdio CD structure set by cdio_open(). @param i_timeout_ms time in milliseconds we will wait for the command to complete. @param p_cdb CDB bytes. All values that are needed should be set on input. We’ll figure out what the right CDB length should be. @param e_direction direction the transfer is to go. @param i_buf Size of buffer @param p_buf Buffer for data, both sending and receiving.
@return 0 if command completed successfully.