#[repr(C)]pub struct iso9660_stat_s {
pub rr: iso_rock_statbuf_t,
pub tm: tm,
pub lsn: lsn_t,
pub size: u32,
pub secsize: u32,
pub total_size: u64,
pub xa: iso9660_xa_t,
pub type_: iso9660_stat_s__bindgen_ty_1,
pub b_xa: bool,
pub filename: __IncompleteArrayField<c_char>,
}Expand description
\brief Unix stat-like version of iso9660_dir
The iso9660_stat structure is not part of the ISO-9660 specification. We use it for our to communicate information in a C-library friendly way, e.g struct tm time structures and a C-style filename string.
@see iso9660_dir
Fields
rr: iso_rock_statbuf_t< Rock Ridge-specific fields
tm: tm< time on entry - FIXME merge with one of entries above, like ctime?
lsn: lsn_t< start logical sector number
size: u32< size of the first extent, in bytes
secsize: u32< size of the first extent, in sectors
total_size: u64xa: iso9660_xa_t< XA attributes
type_: iso9660_stat_s__bindgen_ty_1b_xa: boolfilename: __IncompleteArrayField<c_char>< filename