#[repr(C, packed(1))]pub struct iso9660_xa_s {
pub group_id: u16,
pub user_id: u16,
pub attributes: u16,
pub signature: [c_char; 2],
pub filenum: u8,
pub reserved: [u8; 5],
}Expand description
\brief “Extended Architecture” according to the Philips Yellow Book.
CD-ROM EXtended Architecture is a modification to the CD-ROM specification that defines two new types of sectors. CD-ROM XA was developed jointly by Sony, Philips, and Microsoft, and announced in August 1988. Its specifications were published in an extension to the Yellow Book. CD-i, Photo CD, Video CD and CD-EXTRA have all subsequently been based on CD-ROM XA.
CD-XA defines another way of formatting sectors on a CD-ROM, including headers in the sectors that describe the type (audio, video, data) and some additional info (markers, resolution in case of a video or audio sector, file numbers, etc).
The data written on a CD-XA is consistent with and can be in ISO-9660 file system format and therefore be readable by ISO-9660 file system translators. But also a CD-I player can also read CD-XA discs even if its own `Green Book’ file system only resembles ISO 9660 and isn’t fully compatible.
Note structure is big-endian.
Fields
group_id: u16< 0
user_id: u16< 0
attributes: u16< XA_ATTR_
signature: [c_char; 2]< { ‘X’, ‘A’ }
filenum: u8< file number, see also XA subheader
reserved: [u8; 5]< zero