pub type CdioISO9660FileList_t = CdioList_t;Expand description
\brief A data type for a list of ISO9660 statbuf file pointers returned from the various Cdio iso9660 readdir routines.
Aliased Type
pub struct CdioISO9660FileList_t { /* private fields */ }