pub type cdio_cd_enums = c_int;Expand description
An enumeration for some of the CDIO_CD #defines below. This isn’t really an enumeration one would really use in a program it is to be helpful in debuggers where wants just to refer to the CDIO_CD_ names and get something.