pub type cdio_log_handler_t = Option<unsafe extern "C" fn(level: cdio_log_level_t, message: *const c_char)>;Expand description
This type defines the signature of a log handler. For every message being logged, the handler will receive the log level and the message string.
@see cdio_log_set_handler @see cdio_log_level_t
@param level The log level. @param message The log message.
Aliased Type
pub enum cdio_log_handler_t {
None,
Some(unsafe extern "C" fn(u32, *const i8)),
}