pub type iso_enum1_s = c_uint;Expand description
The following isn’t really an enumeration one would really use in a program; things are done this way so that in a debugger, one can refer to the enumeration value names, such as in a debugger expression and get something. With the more common #define mechanism, the name/value association is lost at runtime.