pub type iso_extension_enum_s = c_uint;Expand description
An enumeration for some of the ISO_EXTENSION_* #defines below. This isn’t really an enumeration one would really use in a program it is here to be helpful in debuggers where wants just to refer to the ISO_EXTENSION_*_ names and get something.