pub type xa_misc_enum_t = c_uint;Expand description
An enumeration for some of the XA_* #defines below. This isn’t really an enumeration one would really use in a program it is to be helpful in debuggers where wants just to refer to the XA_* names and get something. Source: https://psx-spx.consoledev.net/cdromformat/#format-of-a-directory-record